==> jc-1.4.0.tar.gz: soot/util/StationaryArrayList.h <==
// public class soot.util.StationaryArrayList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class 58038509830ef3f4 java_util_ArrayList
// @dep_class 5eb38862705ebedf soot_util_StationaryArrayList

// header file dependencies
// @dep_header java_util_ArrayList

#include "java/util/ArrayList.h"

#ifndef _JC_soot_util_StationaryArrayList_H_
#define _JC_soot_util_StationaryArrayList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_util_StationaryArrayList$sub_refs	_jc_soot_util_StationaryArrayList$sub_refs;
typedef struct _jc_soot_util_StationaryArrayList$sub_nonrefs	_jc_soot_util_StationaryArrayList$sub_nonrefs;
typedef struct _jc_soot_util_StationaryArrayList$refs	_jc_soot_util_StationaryArrayList$refs;
typedef struct _jc_soot_util_StationaryArrayList$nonrefs	_jc_soot_util_StationaryArrayList$nonrefs;
typedef struct _jc_soot_util_StationaryArrayList$object	_jc_soot_util_StationaryArrayList$object;

typedef const struct _jc_soot_util_StationaryArrayList$vmethods	_jc_soot_util_StationaryArrayList$vmethods;
typedef const struct _jc_soot_util_StationaryArrayList$vtable	_jc_soot_util_StationaryArrayList$vtable;
typedef const struct _jc_soot_util_StationaryArrayList$vtype	_jc_soot_util_StationaryArrayList$vtype;

// Constructors
extern void _jc_soot_util_StationaryArrayList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_util_StationaryArrayList$object *);

// Virtual methods
extern jboolean _jc_soot_util_StationaryArrayList$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_util_StationaryArrayList$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_util_StationaryArrayList$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_util_StationaryArrayList$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_StationaryArrayList$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_util_StationaryArrayList$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_soot_util_StationaryArrayList$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_util_StationaryArrayList$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_util_StationaryArrayList$object *);
};

// Vtable
struct _jc_soot_util_StationaryArrayList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_java_util_ArrayList$vmethods	java_util_ArrayList;
	_jc_soot_util_StationaryArrayList$vmethods	soot_util_StationaryArrayList;
};

// Vtype
struct _jc_soot_util_StationaryArrayList$vtype {
	_jc_type			type;
	_jc_soot_util_StationaryArrayList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_StationaryArrayList$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_util_StationaryArrayList$refs {
    _jc_soot_util_StationaryArrayList$sub_refs	soot_util_StationaryArrayList;
    _jc_java_util_ArrayList$sub_refs	java_util_ArrayList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_StationaryArrayList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_StationaryArrayList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_java_util_ArrayList$sub_nonrefs	java_util_ArrayList;
    _jc_soot_util_StationaryArrayList$sub_nonrefs	soot_util_StationaryArrayList;
};

// Object instance structure
struct _jc_soot_util_StationaryArrayList$object {
	_jc_soot_util_StationaryArrayList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_StationaryArrayList$vtype	*vtype;
	_jc_soot_util_StationaryArrayList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_StationaryArrayList$vtype _jc_soot_util_StationaryArrayList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_StationaryArrayList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_StationaryArrayList$class_object;

#endif	/* _JC_soot_util_StationaryArrayList_H_ */

==> jc-1.4.6.tar.gz: soot/util/StationaryArrayList.h <==
// public class soot.util.StationaryArrayList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class 58038509830ef3f4 java_util_ArrayList
// @dep_class 5eb38862705ebedf soot_util_StationaryArrayList

// header file dependencies
// @dep_header java_util_ArrayList

#include "java/util/ArrayList.h"

#ifndef _JC_soot_util_StationaryArrayList_H_
#define _JC_soot_util_StationaryArrayList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_util_StationaryArrayList$sub_refs	_jc_soot_util_StationaryArrayList$sub_refs;
typedef struct _jc_soot_util_StationaryArrayList$sub_nonrefs	_jc_soot_util_StationaryArrayList$sub_nonrefs;
typedef struct _jc_soot_util_StationaryArrayList$refs	_jc_soot_util_StationaryArrayList$refs;
typedef struct _jc_soot_util_StationaryArrayList$nonrefs	_jc_soot_util_StationaryArrayList$nonrefs;
typedef struct _jc_soot_util_StationaryArrayList$object	_jc_soot_util_StationaryArrayList$object;

typedef const struct _jc_soot_util_StationaryArrayList$vmethods	_jc_soot_util_StationaryArrayList$vmethods;
typedef const struct _jc_soot_util_StationaryArrayList$vtable	_jc_soot_util_StationaryArrayList$vtable;
typedef const struct _jc_soot_util_StationaryArrayList$vtype	_jc_soot_util_StationaryArrayList$vtype;

// Constructors
extern void _jc_soot_util_StationaryArrayList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_util_StationaryArrayList$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_util_StationaryArrayList$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_util_StationaryArrayList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_util_StationaryArrayList$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_util_StationaryArrayList$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_StationaryArrayList$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_util_StationaryArrayList$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_soot_util_StationaryArrayList$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_util_StationaryArrayList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_util_StationaryArrayList$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_StationaryArrayList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_java_util_ArrayList$vmethods	java_util_ArrayList;
	_jc_soot_util_StationaryArrayList$vmethods	soot_util_StationaryArrayList;
};

// Vtype
struct _jc_soot_util_StationaryArrayList$vtype {
	_jc_type			type;
	_jc_soot_util_StationaryArrayList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_StationaryArrayList$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_util_StationaryArrayList$refs {
    _jc_soot_util_StationaryArrayList$sub_refs	soot_util_StationaryArrayList;
    _jc_java_util_ArrayList$sub_refs	java_util_ArrayList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_StationaryArrayList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_StationaryArrayList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_java_util_ArrayList$sub_nonrefs	java_util_ArrayList;
    _jc_soot_util_StationaryArrayList$sub_nonrefs	soot_util_StationaryArrayList;
};

// Object instance structure
struct _jc_soot_util_StationaryArrayList$object {
	_jc_soot_util_StationaryArrayList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_StationaryArrayList$vtype	*vtype;
	_jc_soot_util_StationaryArrayList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_StationaryArrayList$vtype _jc_soot_util_StationaryArrayList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_StationaryArrayList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_StationaryArrayList$class_object;

#endif	/* _JC_soot_util_StationaryArrayList_H_ */
